OC.L10N.register(
    "mail",
    {
    "Work" : "Posao",
    "Mail" : "Pošta",
    "Save" : "Save",
    "Connect" : "Poveži se",
    "Password required" : "Potrebna je lozinka",
    "Name" : "naziv",
    "Password" : "Password",
    "None" : "Ništa",
    "Signature" : "Potpis",
    "Cancel" : "Otkaži",
    "General" : "Opšte",
    "Appearance" : "Izgled",
    "Newest first" : "Prvo novije",
    "Oldest first" : "prvo starije",
    "About" : "O programu",
    "Delete" : "Delete",
    "Search" : "Search",
    "Send" : "Pošalji",
    "Refresh" : "Osveži",
    "Ok" : "Ok",
    "Select account" : "Označite nalog",
    "Choose" : "Odaberi",
    "Favorite" : "Omiljene",
    "Read" : "Čitaj",
    "Back" : "Nazad",
    "Description" : "Opis",
    "Create" : "Napravi",
    "Select" : "Obeleži",
    "Comment" : "Komentar",
    "Remove" : "Ukloni",
    "Today" : "Danas",
    "Yesterday" : "јуче",
    "Last month" : "Prošlog meseca",
    "Favorites" : "Omiljene",
    "Other" : "Ostali",
    "Forward" : "Prosledi",
    "Translate" : "Prevedi",
    "Move" : "Premesti",
    "Remove account" : "Ukloni nalog",
    "Folder name" : "Naziv fascikle",
    "Mark all as read" : "Označi sve kao pročitano",
    "Rename" : "Preimenuj",
    "Clear cache" : "Očisti keš",
    "Reply" : "Odgovori",
    "Add" : "Dodaj",
    "Close" : "Zatvori",
    "Body" : "Telo",
    "Date" : "Date",
    "Tags" : "Oznake",
    "Not found" : "Nije nađeno",
    "Deleted" : "Obrisano",
    "Help" : "Pomoć",
    "delete" : "obriši",
    "Edit" : "Izmeni",
    "User" : "Korisnik",
    "Shared" : "Deljeno",
    "All" : "Sve",
    "Continue to %s" : "Nastavi na %s"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
